@@ -1,18 +1,18 @@
 fn main() {
- let mut path = std::path::PathBuf::new();
- path.push(std::env::var_os("OUT_DIR").unwrap());
+ let mut path = std::path::PathBuf::from(std::env::var_os("OUT_DIR").unwrap());
  while path.file_name() != Some(std::ffi::OsStr::new("target")) {
   path.pop();
  }
  path.pop();
  path.push("migrations.toml");
 
- let mut path2 = std::path::PathBuf::new();
- path2.push(std::env::var_os("OUT_DIR").unwrap());
+ println!("cargo:rerun-if-changed={}", path.to_str().unwrap());
+
+ let mut path2 = std::path::PathBuf::from(std::env::var_os("OUT_DIR").unwrap());
  path2.push("migrations.toml");
 
  // docs.rs is a largely read-only filesystem
- if let Ok(_) = std::env::var("DOCS_RS") {
+ if std::env::var("DOCS_RS").is_ok() {
   std::fs::write(&path2, "").unwrap();
   return;
  }
@@ -21,5 +21,5 @@ fn main() {
   std::fs::write(&path, "").unwrap();
  }
 
- std::fs::hard_link(path, path2).ok();
+ std::fs::copy(path, path2).unwrap();
 }
