@@ -1,5 +1,7 @@
 // cargo test --features test --manifest-path turbosql/Cargo.toml -- --nocapture
 
+#![allow(clippy::bool_assert_comparison, clippy::bool_comparison)]
+
 #[cfg(not(feature = "test"))]
 compile_error!("turbosql must be tested with '--features test'");
 #[cfg(not(test))]
@@ -22,6 +24,8 @@ struct PersonIntegrationTest {
  field_u32: Option<u32>,
  field_i32: Option<i32>,
  field_blob: Option<Blob>,
+ field_vec_u8: Option<Vec<u8>>,
+ field_array_u8: Option<[u8; 99]>,
 }
 
 #[test]
@@ -34,6 +38,7 @@ fn integration_test() {
   field_f64: Some(std::f64::consts::PI),
   field_f32: Some(std::f32::consts::E),
   field_blob: None,
+  field_array_u8: Some([1u8; 99]),
   ..Default::default()
  };
 
@@ -44,6 +49,10 @@ fn integration_test() {
 
  assert!(select!(i64 "1").unwrap() == 1);
  assert!(select!(i64 "SELECT 1").unwrap() == 1);
+ assert!(select!(bool "SELECT 1 > ? AS val", 0).unwrap() == true);
+ assert!(select!(bool "SELECT 1 > ? AS val", 2).unwrap() == false);
+ assert!(select!(bool "SELECT 1 > "0" AS val").unwrap() == true);
+ assert!(select!(bool "SELECT 1 > "2" AS val").unwrap() == false);
  assert!(
   execute!("")
    == Err(rusqlite::Error::SqliteFailure(
@@ -57,7 +66,7 @@ fn integration_test() {
 
  assert!(select!(PersonIntegrationTest).unwrap() == row);
  assert!(
-  select!(PersonIntegrationTest "rowid, field_string, field_i64, field_bool, field_f64, field_f32, field_u8, field_i8, field_u16, field_i16, field_u32, field_i32, field_blob FROM personintegrationtest")
+  select!(PersonIntegrationTest "rowid, field_string, field_i64, field_bool, field_f64, field_f32, field_u8, field_i8, field_u16, field_i16, field_u32, field_i32, field_blob, field_vec_u8, field_array_u8 FROM personintegrationtest")
    .unwrap()
    == row
  );
@@ -81,6 +90,35 @@ fn integration_test() {
  assert!(select!(Vec<PersonIntegrationTest>).unwrap() == vec![row.clone()]);
  assert!(select!(Option<PersonIntegrationTest>).unwrap() == Some(row.clone()));
 
+ let field_u8 = row.field_u8;
+ // assert!(select!(PersonIntegrationTest r#"WHERE field_u8 = $field_u8"#).unwrap() == row);
+ assert!(select!(PersonIntegrationTest "WHERE field_u8 = " field_u8).unwrap() == row);
+ assert!(select!(PersonIntegrationTest "WHERE field_u8 = " field_u8 " AND 1 = " 1).unwrap() == row);
+ assert!(select!(PersonIntegrationTest "WHERE field_u8 = " field_u8 " AND 1 = " 0).is_err());
+
+ let field_string = row.field_string.clone();
+ // assert!(select!(PersonIntegrationTest r#"WHERE field_string = $field_string"#).unwrap() == row);
+ // assert!(select!(PersonIntegrationTest r#"WHERE field_string = $field_string"#).unwrap() == row);
+ assert!(select!(PersonIntegrationTest "WHERE field_string = " field_string " ").unwrap() == row);
+ assert!(select!(PersonIntegrationTest "WHERE field_string = " field_string).unwrap() == row);
+
+ // assert!(
+ //  select!(PersonIntegrationTest "WHERE field_u8 = $field_u8 AND 1 = ?", 1, 3, 4).unwrap() == row
+ // );
+
+ // assert!(select!(PersonIntegrationTest "WHERE 1 = ? AND field_u8 = $field_u8", 1).unwrap() == row);
+
+ assert!(
+  select!(PersonIntegrationTest "WHERE field_string = ?", row.field_string.as_ref().unwrap())
+   .unwrap()
+   == row
+ );
+
+ assert!(
+  select!(String "field_string FROM personintegrationtest").unwrap()
+   == row.field_string.as_deref().unwrap()
+ );
+
  assert!(select!(PersonIntegrationTest "WHERE field_u8 = ?", row.field_u8).unwrap() == row);
  assert!(
   select!(Vec<PersonIntegrationTest> "WHERE field_u8 = ?", row.field_u8).unwrap()
@@ -118,25 +156,24 @@ fn integration_test() {
   select!(i64 "field_u8 FROM personintegrationtest").unwrap() == row.field_u8.unwrap().into()
  );
 
- assert!(
-  select!(bool "field_string = ? FROM personintegrationtest", "Arthur Schopenhauer").unwrap()
-   == false
+ assert_eq!(
+  select!(bool "field_string =?FROM personintegrationtest", "Arthur Schopenhauer").unwrap(),
+  false
  );
  let new_row = row.clone();
- assert!(
-  select!(bool "field_string = ? FROM personintegrationtest", new_row.field_string.unwrap())
-   .unwrap()
-   == true
+ assert_eq!(
+  select!(bool "field_string =?FROM personintegrationtest", new_row.field_string.unwrap()).unwrap(),
+  true
  );
  // this incorrectly consumes row:
  // assert!(select!(bool "field_string = ? FROM personintegrationtest", row.field_string.unwrap()).unwrap() == true);
 
  // select!(PersonIntegrationTest "WHERE field_string = ?", row.field_string.unwrap());
 
- assert!(
+ assert_eq!(
   select!(bool "field_string = ? FROM personintegrationtest", row.clone().field_string.unwrap())
-   .unwrap()
-   == true
+   .unwrap(),
+  true
  );
 
  assert!(
@@ -162,6 +199,11 @@ fn integration_test() {
  // let result = select!(Vec<(Person.name, Person.age)>)?;
  // let result = select!(Vec<(Person.name, Person.age)> "WHERE ...")?;
 
+ // let result = select!({ name, "age >= 18 AS" adult: bool } "FROM" Person)?;
+ // let result = select!({ name: String, "age >= 18 AS" adult: bool } "FROM person")?;
+ // let_select!(name: String, "age >= " adult_age " AS " adult: bool "FROM person")?;
+ // let result = select!(( "name AS" String, "age >= 18 AS" bool ) "FROM person")?;
+
  // DELETE
 
  assert!(execute!("DELETE FROM personintegrationtest").is_ok());
